==> tomboy-ng_0.31a.orig.tar.gz: tomboy-ng_0.31a-1/README.md <==
### tomboy-ng 

tomboy-ng is a note taking app that works and syncronises between Linux, Windows and MacOS. It will also Sync to Tomdroid on Android. It features a rich text markup, printing, spell check, backup and snapshot capability. Import and export (plain text, RFT, MarkDown). It has Tomboy's automatic linking between notes, searching abilities, NoteBooks and a similar interface. 

Importantly, tomboy-ng has little or in most cases no dependancies and so is an easy and lightweight install. Most people use the binary install kits but you are welcome to build from source. Download from the [Wiki Download Page](https://github.com/tomboy-notes/tomboy-ng/wiki/Download_Release)
<p align="center"><img src="https://github.com/tomboy-notes/tomboy-ng/blob/master/doc/gallery/tomboyNG_hero.png"></p>
<p align="center"><img src="https://github.com/xypd/tomboy-ng/blob/master/doc/gallery/tomboy-ng_screens.png"></p>

Please see the [Wiki](https://github.com/tomboy-notes/tomboy-ng/wiki) for further information.
We use GitHub to store sources and track bugs, see [Tomboy](https://github.com/tomboy-notes/tomboy-ng).

The tomboy-ng homepage also is part of the Tomboy homepage [here](https://wiki.gnome.org/Apps/Tomboy).

If you're interested in discussing tomboy-ng, please consider our mailing list.
To subscribe, visit [here](http://lists.beatniksoftware.com/listinfo.cgi/tomboy-list-beatniksoftware.com)
or just send your questions and suggestions to <tomboy-list@beatniksoftware.com>.

Copyright (C) 2018,2019,2020 David Bannon <dbannon@internode.on.net>

---

==> tomboy-ng_0.32.orig.tar.gz: tomboy-ng_0.32-1/README.md <==
### tomboy-ng 

tomboy-ng is a note taking app that works and syncronises between Linux, Windows and MacOS. It will also Sync to Tomdroid on Android. It features a rich text markup, printing, spell check, backup and snapshot capability. Import and export (plain text, RFT, MarkDown). It has Tomboy's automatic linking between notes, searching abilities, NoteBooks and a similar interface. 

Importantly, tomboy-ng has little or in most cases no dependancies and so is an easy and lightweight install. It is easily installed for Debian Bullseye and its derivatives directly from the Debian Repositories or you can download an install kit from here. You are, of course, welcome to build from source. Download from the [Wiki Download Page](https://github.com/tomboy-notes/tomboy-ng/wiki/Download_Release)
<p align="center"><img src="https://github.com/tomboy-notes/tomboy-ng/blob/master/doc/gallery/tomboyNG_hero.png"></p>
<p align="center"><img src="https://github.com/xypd/tomboy-ng/blob/master/doc/gallery/tomboy-ng_screens.png"></p>

Please see the [Wiki](https://github.com/tomboy-notes/tomboy-ng/wiki) for further information.
We use GitHub to store sources and track bugs, see [Tomboy](https://github.com/tomboy-notes/tomboy-ng).

The tomboy-ng homepage also is part of the Tomboy homepage [here](https://wiki.gnome.org/Apps/Tomboy).

If you're interested in discussing tomboy-ng, please consider our mailing list.
To subscribe, visit [here](http://lists.beatniksoftware.com/listinfo.cgi/tomboy-list-beatniksoftware.com)
or just send your questions and suggestions to <tomboy-list@beatniksoftware.com>.

Copyright (C) 2018,2019,2020,2021 David Bannon <dbannon@internode.on.net>

---
